@@ -8,6 +8,7 @@ import socketio
 from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer, RTCSessionDescription
 from aiortc.contrib.media import MediaPlayer, MediaRelay
 from datetime import datetime
+
 try:
     import picamera
 except:
@@ -37,19 +38,22 @@ class BroadcastThread(Thread):
 
 
 class GSPeerConnectionBroadcasterPiCaller:
-    def __init__(self, gsdbs, camera, oncommand=None):
+    def __init__(self, gsdbs, camera, oncommand=None, setChannel=None):
         self.sio = socketio.AsyncClient()
         self.gsdbs = gsdbs
         self.camera = camera
         self._logger = logging.getLogger(__name__)
         self.oncommand = oncommand
+        self.setChannel = setChannel
 
     async def startSocket(self):
         self._logger.debug("start broadcast socket")
         await GSPeerConnectionBroadcasterPiSocket.create(self.sio,
                                                          self.gsdbs,
                                                          self.camera,
-                                                         self.oncommand)
+                                                         self.oncommand,
+                                                         self.setChannel
+                                                         )
 
 
 class GSPeerConnectionBroadcasterPiSocket:
@@ -72,7 +76,7 @@ class GSPeerConnectionBroadcasterPiSocket:
         return relay.subscribe(microfon.audio)
 
     @classmethod
-    async def create(cls, sio, gsdbs, camera, oncommand,setChannel=None):
+    async def create(cls, sio, gsdbs, camera, oncommand, setChannel=None):
         self = GSPeerConnectionBroadcasterPiSocket()
 
         self.rtconfiList = []
@@ -173,7 +177,6 @@ class GSPeerConnectionBroadcasterPiSocket:
                     if isinstance(message, str) and message.startswith('{"command'):
                         subprocess_cmd(json.loads(message)["command"])
 
-
             transceiver = pc.addTransceiver("video", direction="sendonly")
 
             capabilities = RTCRtpSender.getCapabilities("video")
